<?php
/**
 * @file mod_roomReservationConfigPage.inc
 * The configuration page
 * @author Roland Hieber (roland.hieber@wilhelm-gym.net)
 * @date 24.06.2008
 * 
 * Copyright © 2007 Roland Hieber
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

require_once("ctrl.inc");
require_once("mod_room-reservation/mod_roomReservationPage.inc");
require_once("mod_room-reservation/mod_roomReservationTimesliceListBox.inc");
require_once("mod_room-reservation/mod_roomReservationRoomWhitelistListBox.inc");

/** @todo document */
class mod_roomReservationConfigPage extends mod_roomReservationPage {

  protected $bPostShowWeekend;
  protected $bPostShowLessons;
  protected $asMessages = array();
  protected $otlb;
  protected $orwlb;
  
  public function __construct(mod_roomReservationConfig &$oCfg) {
    parent::__construct($oCfg);
    $this->otlb = new mod_roomReservationTimesliceListBox($this->oCfg);
    $this->orwlb = new mod_roomReservationRoomWhitelistListBox($this->oCfg);
    $this->setTitle(_c("room-reservation:Configuration"));
    $this->setIcon("mod_room-reservation_config");
  }

  public function processRequestVariables() {
    // default values
    $this->bPostShowWeekend = $this->oCfg->isShowWeekend();
    $this->bPostShowLessons = $this->oCfg->isShowLessons();
    
    if(isset($_POST["mod_roomReservationConfigPage"])) {
      if(isset($_POST["mod_roomReservationConfigPage"]["showweekend"])) {
        $this->bPostShowWeekend = 
          ($_POST["mod_roomReservationConfigPage"]["showweekend"] == true);
      }
      
      if(isset($_POST["mod_roomReservationConfigPage"]["showlessons"])) {
        $this->bPostShowLessons = 
          ($_POST["mod_roomReservationConfigPage"]["showlessons"] == true);
      }
      
      // process the request
      if(isset($_POST["mod_roomReservationConfigPage"]["submit"])) {
        $this->oCfg->setShowWeekend($this->bPostShowWeekend);
        $this->oCfg->setShowLessons($this->bPostShowLessons);
        try {
          $this->oCfg->writeConfig();
        } catch(Exception $e) {
          $this->asMessages[] = $e->getMessage();
        }
      }
    }
  }
  
  public function doShow() {
    // error messages
    if(count($this->asMessages) > 0) {
      printf("<p>%s</p>", nl2br(q(join("\n", $this->asMessages))));
    }
    
    // first column
    echo "<table border='0' cellspacing='10' cellpadding='0'><tr>".
    	"<td style='width:50%;'>\n";
    
    GroupBox(_c("room-reservation:Available rooms"), "host");
    printf("<p>%s</p>", _c("room-reservation:The following rooms are ".
    	"available for booking:"));
    echo "<div style='margin:8px;'>";
    $this->orwlb->show();
    echo "</div>\n";
    _GroupBox();
    
    GroupBox(_("Privileges"), "keys");
    $asAdminGroups = rrPrivilegedGroups("mod_roomreservation_admin");
    $asBookGroups = rrPrivilegedGroups("mod_roomreservation_book");
    $asViewGroups = rrPrivilegedGroups("mod_roomreservation_view");
    echo sprintf("<p>%s</p>\n<p>%s</p>\n<p>%s</p>", _c("room-reservation:This is ".
      "a short summary of the privileges related to the room reservation ".
      "schedulde and the groups which have them assigned."),
      sprintf(_c("room-reservation:If one of these privileges is not assigned to ".
      "any group, all users on this server are allowed to perform the specified ".
      "action. Please use the %sgroup administration%s to assign and revoke ".
      "privileges."), "<a href='/idesk/admin/act/groups.php'>", "</a>"),
      _c("room-reservation:Please note that every group with the booking ".
    	"privilege can also implicitly view the booking table and every group with ".
    	"the administration privilege can also implicitly book and view the ".
    	"booking table."));
    echo "<p><table style='width:100%'><tr>\n";
    echo sprintf("<td>%s%s</td><td>%s</td>\n", icon("keys"),
      _("View the booking table").":", $asViewGroups == array() ?
      _c("room-reservation:all users") : icon("act-group") . join(", ", 
      array_map("getGroupName", $asViewGroups)));
    echo "</tr><tr>\n";
    echo sprintf("<td>%s%s</td><td>%s</td>\n", icon("keys"),
      _("Book rooms").":", $asBookGroups == array() ?
      _c("room-reservation:all users") : icon("act-group") . join(", ",
      array_map("getGroupName", $asBookGroups)));
    echo "</tr><tr>\n";
    echo sprintf("<td>%s%s</td><td>%s</td>\n", icon("keys"),
      _("Administration of the room reservation schedule"),
      $asAdminGroups == array() ? _c("room-reservation:no users") :
      icon("act-group") . join(", ", array_map("getGroupName", $asAdminGroups)));
    echo "</tr></table></p>\n";
    _GroupBox();

    // second column
    echo "</td><td><!--second row-->\n";
    
    GroupBox(_c("room-reservation:Periods"), "mod_room-reservation_timeslice");
    printf("<p>%s</p>", _c("room-reservation:Here you can fill in the ".
    	"periods where bookings can be undertaken. A booking period can ".
    	"e.&nbsp;g. correspond to a lesson."));
    echo "<div style='margin:8px;'>";
    $this->otlb->show();
    echo "</div>\n";
    _GroupBox();
    
    GroupBox(_c("room-reservation:Further options"), "manage");
    printf("<div style='margin:8px;'><form action='%s' method='post'>".
    	"<table><tr>\n", $_SERVER["PHP_SELF"]);

    printf("<td><input type='hidden' name='mod_roomReservationConfigPage".
    	"[showweekend]' value='0' /><%s name='mod_roomReservationConfigPage".
    	"[showweekend]' id='mod_roomReservationConfigPageShowWeekend' ".
    	"value='1' %s /></td><td><label for='".
    	"mod_roomReservationConfigPageShowWeekend'><b>%s</b></label><br />".
    	"<span class='mod_roomReservationConfigPageExplanation'>%s</span></p>",
      $GLOBALS["smlchk"], $this->bPostShowWeekend ? "checked='checked' " : "",
      _c("room-reservation:Show weekend"), _c("room-reservation:If ".
      "selected, the weekdays saturday and sunday are also shown in the ".
      "booking table."));

    echo "</tr><tr>\n";
    printf("<td><input type='hidden' name='mod_roomReservationConfigPage".
    	"[showlessons]' value='0' /><%s name='mod_roomReservationConfigPage".
    	"[showlessons]' id='mod_roomReservationConfigPageShowLessons' ".
    	"value='1'%s /></td><td><label for='".
    	"mod_roomReservationConfigPageShowLessons'><b>%s</b></label><br />".
    	"<span class='mod_roomReservationConfigPageExplanation'>%s</span></p>",
      $GLOBALS["smlchk"], $this->bPostShowLessons ? "checked='checked' " : "",
      _c("room-reservation:Show &bdquo;lesson&rdquo; texts"),
      _c("room-reservation:Check this box to show texts like ".
      	"&bdquo;<i>n</i>th lesson&rdquo in the booking page. If this box is ".
      	"unchecked, none of these texts are shown."));
      
    printf("</tr><tr><td colspan='2'><%s name='mod_roomReservationConfigPage".
    	"[submit]' value='%s' /></td>", $GLOBALS["stdbtn"], _("OK"));
    echo "</tr></table></form></div>\n";
    _GroupBox();

    echo "</td></tr></table>\n";
  }
}
?>